//
//  WebContentViewCtrl.m
//  MoontanRoad
//
//  Created by 홍승욱 on 12. 12. 6..
//  Copyright (c) 2012년 홍승욱. All rights reserved.
//

#import "WebContentViewCtrl.h"

#import "AppDelegate.h"
//#import "ShopInfoViewCtrl.h"
//#import "PhotoGalleryViewCtrl.h"
//#import "EventListViewCtrl.h"
//#import "MovViewCtrl.h"

@interface WebContentViewCtrl () {
    CGRect _webViewFrame;
    BOOL _bRefresh;
}

- (NSURL *)smartURLForString:(NSString *)str;

@end

@implementation WebContentViewCtrl

@synthesize webView = _webView;
//@synthesize contentUrl = _contentUrl;
@synthesize strTitle = _strTitle;
@synthesize ownerViewCtrl = _ownerViewCtrl;

- (id)initWithURL:(NSString*)url withTitle:(NSString*)title
{
    self = [super init];//[super initWithTitle:title];
    if (self) {
        _bRefresh = YES;
        _contentUrl = [[NSString alloc] initWithString:url];
        
        _webViewFrame = CGRectMake(0, 0, self.view.bounds.size.width, self.view.bounds.size.height);
        _webView = [[UIWebView alloc] initWithFrame:_webViewFrame];
        [_webView setDelegate:self];
        [self.view addSubview:_webView];
        
    }
    return self;
}

- (void)viewWillAppear:(BOOL)animated
{
    if (_bRefresh) {
        [_lbTitle setText:_strTitle];
    }
}

- (void)viewDidAppear:(BOOL)animated
{
    if (_bRefresh) {
        NSMutableURLRequest *request = [NSMutableURLRequest requestWithURL:[self smartURLForString:_contentUrl]];
        [_webView loadRequest:request];
    }
}

- (void)viewWillDisappear:(BOOL)animated
{
    if (_bRefresh) {
        [_webView removeFromSuperview];
//        [_webView release];
        _webView = nil;
        
        _webView = [[UIWebView alloc] initWithFrame:_webViewFrame];
        [_webView setDelegate:self];
        [self.view addSubview:_webView];
    }
}

#pragma mark - Member Func

- (NSString*)contentUrl
{
    return _contentUrl;
}

- (void)setContentUrl:(NSString *)contentUrl
{
    _bRefresh = YES;
    _contentUrl = [[NSString alloc] initWithString:contentUrl];
    NSMutableURLRequest *request = [NSMutableURLRequest requestWithURL:[self smartURLForString:_contentUrl]];
    [_webView loadRequest:request];
    
}

- (NSURL *)smartURLForString:(NSString *)str
{
    NSURL *     result;
    NSString *  trimmedStr;
    NSRange     schemeMarkerRange;
    NSString *  scheme;
    
    assert(str != nil);
    
	
    result = nil;
    
    trimmedStr = [str stringByTrimmingCharactersInSet:[NSCharacterSet whitespaceCharacterSet]];
    if ( (trimmedStr != nil) && (trimmedStr.length != 0) ) {
        schemeMarkerRange = [trimmedStr rangeOfString:@"://"];
        
        if (schemeMarkerRange.location == NSNotFound) {
            result = [NSURL URLWithString:[NSString stringWithFormat:@"http://%@", trimmedStr]];
        } else {
            scheme = [trimmedStr substringWithRange:NSMakeRange(0, schemeMarkerRange.location)];
            assert(scheme != nil);
            
            if ( ([scheme compare:@"http"  options:NSCaseInsensitiveSearch] == NSOrderedSame)
				|| ([scheme compare:@"https" options:NSCaseInsensitiveSearch] == NSOrderedSame) ) {
                result = [NSURL URLWithString:trimmedStr];
            } else {
                // It looks like this is some unsupported URL scheme.
            }
        }
    }
    
    return result;
}

#pragma mark - UIWebView delegate

- (BOOL)webView:(UIWebView *)webView shouldStartLoadWithRequest:(NSURLRequest *)request navigationType:(UIWebViewNavigationType)navigationType
{
    NSLog(@"%@", request);
    
    if ([[request.URL absoluteString] hasPrefix:@"http://bus.gimhae.go.kr"]
        || [[request.URL absoluteString] hasPrefix:@"http://tour.gimhae.go.kr/"]
        || [[request.URL absoluteString] hasPrefix:@"http://m.gimhae.go.kr/"]) {
        [[UIApplication sharedApplication] openURL:[NSURL URLWithString:[request.URL absoluteString]]];
        return NO;
    }
    
    if ([[request.URL absoluteString] isEqualToString:@"http://gohome/"]) {
        [self.navigationController popViewControllerAnimated:YES];
        //[_webView loadHTMLString:@"" baseURL:[NSURL URLWithString:@""]];
        return NO;
    }
    
    
    if ([_webView.request.URL absoluteString] != nil &&
        [[request.URL absoluteString] isEqualToString:@"about:blank"]) {
        [self.navigationController popViewControllerAnimated:YES];
        return NO;
    }
    
    if (![[request.URL absoluteString] isEqualToString:@"about:blank"]) {
        [[GP_DELEGATE loadingView] setHidden:NO];
    }
    return YES;
}

- (void)webViewDidFinishLoad:(UIWebView *)webView {
    NSString *title = [webView stringByEvaluatingJavaScriptFromString: @"document.title"];
    [webView stringByEvaluatingJavaScriptFromString:@"document.getElementById('sheader').style.display = 'none'"];
    [_lbTitle setText:title];
    [[GP_DELEGATE loadingView] setHidden:YES];
}

- (void)webView:(UIWebView *)webView didFailLoadWithError:(NSError *)error {
    
    [[GP_DELEGATE loadingView] setHidden:YES];
    UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"알림" message:@"정보를 조회할 수 없습니다. 다시 시도해 주세요." delegate:nil cancelButtonTitle:@"확인" otherButtonTitles:nil];
    [alert show];
//    [alert release];

    [self btnBack_clicked];
}


#pragma mark - Btn Action
- (void)btnBack_clicked
{
    if ([[_webView.request.URL absoluteString] isEqualToString:_contentUrl]) {
        [self.navigationController popViewControllerAnimated:YES];
    }
    else {
        [_webView stringByEvaluatingJavaScriptFromString:@"history.go(-1)"];
    }
}

@end
